#ifndef GDHCPD_get_ranges_from_current_scope_H
#   define GDHCPD_get_ranges_from_current_scope_H

extern struct w *widgets;

char * get_ranges_from_current_scope();

#endif
